@@ -44,9 +44,6 @@ class PersistedRmq(object):
 
     async def init_mq(self):
         await self.connect()
-        if self.on_message:
-            self.timestamp = int(time.time() * 1000)
-            await self.set('client-map', self.lock_key, self.timestamp)
 
     async def set(self, prefix, key, value):
         await self.conn.set(f'{prefix}:{key}', value, expire=3600 * 24 * 3)
@@ -74,7 +71,7 @@ class PersistedRmq(object):
 
     async def duplicate(self) -> bool:
         ts = await self.get('client-map', self.lock_key)
-        logging.error(f'duplicate:{ts} vs {self.timestamp}')
+        logging.error(f'key:{self.lock_key} duplicate:{ts} vs {self.timestamp}')
         return int(ts) != self.timestamp
 
     async def __flush(self):
@@ -100,6 +97,9 @@ class PersistedRmq(object):
             await self.close()
             return
         await self.hash_del()
+        self.timestamp = int(time.time() * 1000)
+        logging.error(f'{self.lock_key} registed at {self.timestamp}')
+        await self.set('client-map', self.lock_key, self.timestamp)
         logging.error(f'进入订阅:{self.subscribe_chn}')
         chs = await self.conn.subscribe(self.subscribe_chn)
         while True:
